@@ -34,8 +34,7 @@ __status__ = "Development"
 #  *
 #  * The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  *
-#  *    2019        Do Kester
+#  *    2019 - 2020 Do Kester
 
 
 class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
@@ -50,7 +49,6 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
     by itself.
     Booleans that contain unknowns should be coded as categorial.
 
-    ..math::
         f( x:p ) = DTM
                     \left => DTM (or None)
                     \rite => DTM (or None)
@@ -134,6 +132,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
             Will the model modify dimension and/or split/mask
         dynamic : bool (True)
             Will the model grow/shrink
+
         """
 
         Modifiable.__init__( self, modifiable=modifiable )
@@ -176,7 +175,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 
 
         param = [0.0] * nparams
-#        super( DecisionTreeModel, self ).__init__( nparams, ndim=ndim, copy=copy,
+
         LinearModel.__init__( self, nparams, ndim=ndim, copy=copy,
                     params=param, **kwargs )
 
@@ -187,16 +186,13 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
             setatt( self, "itypes", itypes )
             setatt( self, "ncomp", ( 0x1 << depth ) - 1 )
             setatt( self, "nsplit", 3 )
-#            self.setPrior( 0, prior=UniformPrior( limits=[0.0,1.0] ) )
             self.setLimits( 0, 1 )
         else :
             setatt( self, "growPrior", copy.growPrior )
             setatt( self, "ncomp", copy.ncomp )
             setatt( self, "nsplit", copy.nsplit )
             setatt( self, "itypes", copy.itypes )
-#            self.setPrior( copy.priors )
 
-#        print( "==========\n", self, self.itypes )
         gen = self.walk()
         child = next( gen )     # skip root
         while True :
@@ -207,7 +203,6 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
             if child.itypes is not None :
                 del( child.itypes )
                 del( child.priors )
-#            print( child, child.itypes )
 
         if code is not None :
             self = self.decode( code, kdim, split, 0 )
@@ -236,6 +231,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
         return dtm
 
     def setSplitOrMask( self, itype, split ) :
+        """ For internal use only """
 
         if itype == 0 :         ## float
             setatt( self, "split", split )
@@ -313,6 +309,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
         return res
 
     def recursiveResult( self, xdata, params, kpar, plist, res ) :
+        """ For internal use only """
 
         pl1, pl2 = self.partitionList( xdata, plist )
 
@@ -358,6 +355,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
         return part
 
     def recursivePartial( self, xdata, kpar, plist, part ) :
+        """ For internal use only """
 
         pl1, pl2 = self.partitionList( xdata, plist )
 
@@ -394,6 +392,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
         return numpy.asarray( self.recursiveOrder( xdata, plist ), dtype=int )
 
     def recursiveOrder( self, xdata, plist ) :
+        """ For internal use only """
 
         pl1, pl2 = self.partitionList( xdata, plist )
 
@@ -449,6 +448,7 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
 
 
     def recursiveName( self, name, indent, kpar, ids=False ) :
+        """ For internal use only """
         if ids :
             if self.parent is None :
                 name += " (%d)" % id( self )
@@ -533,6 +533,21 @@ class DecisionTreeModel( Modifiable, Dynamic, LinearModel ):
         return ( [c1,c2], [self.dimension] + d1 + d2, [sm] + s1 + s2 )
 
     def decode( self, code, kdim, splim, kbr ) :
+        """
+        Resurrect the DTM from the code generated by encode().
+        For internal use in the Constructor.
+
+        Parameters
+        ----------
+        code : list
+            of (list or 1 or 2), encoding the structure of DTM
+        dims : list
+            of dimensions at the branches
+        splim : list
+            of split/mask values at the branches
+        kbr : int
+            counter (start at 0)
+        """
 
         if code == 1 :
             return self, kbr-1
