@@ -27,13 +27,13 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2018 Do Kester
+#  *    2016 - 2020 Do Kester
 
 
 class LaplacePrior( Prior ):
     """
     Laplace prior distribution.
-    .. math::
+
         Pr( x ) = exp( - |x - center| / scale )
 
     By default: center = 0.0 and scale = 1.
@@ -55,10 +55,12 @@ class LaplacePrior( Prior ):
         center of the Laplace prior
     scale : float
         scale of the Laplace prior
-    lowLimit : float
-        low limit (inactive for now)
-    highLimit : float
-        high limit ( inactive for now)
+
+    Attributes from Prior
+    --------------------=
+    lowLimit, highLimit, deltaP, _lowDomain, _highDomain
+
+    lowLimit and highLimit cannot be used in this implementation.
 
     """
 
