@@ -37,7 +37,7 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2011 Do Kester, SRON (JAVA code)
-#  *    2016 - 2018 Do Kester
+#  *    2016 - 2020 Do Kester
 
 
 class Model( FixedModel ):
@@ -45,7 +45,7 @@ class Model( FixedModel ):
     Model implements the common parts of (compound) models.
     It is the last common anchestor of all Models.
 
-    Models can be handled by the **Fitter** classes.
+    Models can be handled by the Fitter classes.
 
     A model consists of one or more instantiations of (base) models which
     are concatenated in a chain of models using various operations
@@ -53,7 +53,7 @@ class Model( FixedModel ):
     i.e. the output of the left-hand process in used as input of the
     right-hand process.
 
-    Methods defined in `BaseModel` as eg. `baseResult()` are recursively called
+    Methods defined in BaseModel as eg. baseResult() are recursively called
     here as result(). They are the ones used in the fitters.
 
     The Model is the place where model-related items are kept, like parameters,
@@ -155,6 +155,11 @@ class Model( FixedModel ):
             model to be copied (default: None)
         params : array_like
             initial parameters of the model
+        fixed : None or dictionary of {int:float|Model}
+            int         index of parameter to fix permanently.
+            float|Model values for the fixed parameters.
+            Attribute fixed can only be set in the constructor.
+            See: @FixedModel
 
         """
         super( Model, self ).__init__( nparams=nparams, ndim=ndim, copy=copy,
@@ -250,17 +255,6 @@ class Model( FixedModel ):
             i += 1
         return i
 
-#   TBC if needed
-    def hasNoNullModel( self, model ):
-        """
-        Return True if the (compound) model contains a NullModel.
-        """
-        while model is not None :
-            if model.isNullModel() :
-                return False
-            model = model._next
-        return True
-
     def isNullModel( self ) :
         """
         Return True if the model has no parameters (a NullModel).
@@ -326,7 +320,7 @@ class Model( FixedModel ):
         and when needed these attributes are taken from there, or stored there.
 
         The operation (addition in this case) is always with the total result of the
-        existing chain. For the use of "brackets" in a chain use ContainerModel.
+        existing chain. For the use of "brackets" in a chain use BracketModel.
 
         Parameters
         ----------
@@ -876,10 +870,10 @@ class Model( FixedModel ):
     def setLimits( self, lowLimits=None, highLimits=None ):
         """
         Sets the limits for the parameters of the compound model.
-        <br>
+
         1. It is valid to insert for either parameter a None value
-        indicating no lower/upper limits.<br>
-        2. When a lowerlimit >= upperlimit no limits are enforced.<br>
+        indicating no lower/upper limits.
+        2. When a lowerlimit >= upperlimit no limits are enforced.
         It only works in *Fitter classes which support it.
 
         Parameters
@@ -1101,6 +1095,8 @@ class Model( FixedModel ):
         """
         Return the i-th parameter.
 
+        >>> p_i = model[i]
+
         Parameters
         ----------
         i : int
@@ -1113,6 +1109,10 @@ class Model( FixedModel ):
         """
         Return the result of the model.
 
+        >>> y = model( x )
+        is equivalent to
+        >>> y = model.result( x, model.parameters )
+
         Parameters
         ----------
         x : (list of) float
@@ -1125,6 +1125,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using += operator.
 
+        >>> model1 += model2
+
         Parameters
         ----------
         model : Model
@@ -1138,6 +1140,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using + operator.
 
+        >>> model1 = model2 + model3
+
         Parameters
         ----------
         model : Model
@@ -1150,6 +1154,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using -= operator.
 
+        >>> model1 -= model2
+
         Parameters
         ----------
         model : Model
@@ -1163,6 +1169,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using - operator.
 
+        >>> model1 = model2 - model3
+
         Parameters
         ----------
         model : Model
@@ -1175,6 +1183,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using *= operator.
 
+        >>> model1 *= model2
+
         Parameters
         ----------
         model : Model
@@ -1188,6 +1198,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using * operator.
 
+        >>> model1 = model2 * model3
+
         Parameters
         ----------
         model : Model
@@ -1200,6 +1212,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using /= operator.
 
+        >>> model1 /= model2
+
         Parameters
         ----------
         model : Model
@@ -1213,6 +1227,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using / operator.
 
+        >>> model1 = model2 / model3
+
         Parameters
         ----------
         model : Model
@@ -1225,6 +1241,10 @@ class Model( FixedModel ):
         """
         Method for making compound models using |= operator.
 
+        >>> model1 |= model2
+
+        Use the results of model1 as input for model2.
+
         Parameters
         ----------
         model : Model
@@ -1238,6 +1258,8 @@ class Model( FixedModel ):
         """
         Method for making compound models using | (pipe) operator.
 
+        >>> model1 = model2 | model3
+
         Parameters
         ----------
         model : Model
@@ -1250,7 +1272,7 @@ class Model( FixedModel ):
     def testPartial( self, xdata, params ):
         """
         A test routine to check the calculation of the partial derivatives.
-        <br>
+
         It is compared to a numerical calculation.
 
         Parameters
