@@ -1,6 +1,7 @@
 # run with : python3 -m unittest TestModels.TestModels.testGaussModel
 
 import unittest
+import os
 import numpy as numpy
 from astropy import units
 import matplotlib.pyplot as plt
@@ -41,6 +42,10 @@ class TestModels( unittest.TestCase ):
     Author:      Do Kester
 
     """
+    def __init__( self, testname ):
+        super( ).__init__( testname )
+        self.doplot = ( "DOPLOT" in os.environ and os.environ["DOPLOT"] == "1" )
+
     def testToString( self ) :
         model = PadeModel( 1, 2 )
         model += PolynomialModel( 0 )
@@ -51,161 +56,25 @@ class TestModels( unittest.TestCase ):
         model = PadeModel( 1, 2 )
         model += PolynomialModel( 1 )
         print( model )
+        print( model.shortName() )
 
-    def plotall( self ) :
-        self.plotArctanModel( )
-        self.plotConstantModel( )
-        self.plotEtalonModel( )
-        self.plotExpModel( )
-        self.plotVoigtModel( )
-        self.plotPseudoVoigtModel( )
-        self.plotLorentzModel( )
-        self.plotLogisticModel( )
-        self.plotFreeShapeModel( )
-        self.plotGaussModel( )
-        self.plotGaussPlusBackgroundModel( )
-        self.plotHarmonicModel( )
-        self.plotPolynomialModel( )
-        self.plotChebyshevPolynomialModel( )
-        self.plotPadeModel( )
-        self.plotPowerLawModel( )
-        self.plotPowerModel( )
-        self.plotRadialVelocityModel( )
-        self.plotSincModel( )
-        self.plotSineModel( )
-        self.plotSineAmpModel( )
-        self.plotSineSplineModel( )
-        self.plotSineSplineDriftModel( )
-        self.plotSineDriftModel( )
-        self.plotBSplinesModel( )
-        self.plotSplinesModel( )
-
-    def plotArctanModel( self ) :
-        self.testArctanModel( plot=True )
-
-    def plotConstantModel( self ) :
-        self.testConstantModel( plot=True )
-
-    def plotEtalonModel( self ) :
-        self.testEtalonModel( plot=True )
-
-    def plotExpModel( self ) :
-        self.testExpModel( plot=True )
-
-    def plotVoigtModel( self ) :
-        self.testVoigtModel( plot=True )
-        xx = numpy.linspace( -1, +1, 1001 )
-        par = numpy.asarray( [1.2,-0.2,0.3,0.3], dtype=float )
-        plt.plot( xx, VoigtModel().result( xx, par ), 'r-', linewidth=2 )
-        plt.plot( xx, GaussModel().result( xx, par[[0,1,2]] ), 'b-' )
-        pg = par.copy()
-        pg[3] = 0
-        plt.plot( xx, LorentzModel().result( xx, par[[0,1,3]] ), 'g-' )
-        plt.plot( xx, VoigtModel().result( xx, pg ), 'r--' )
-        pg = par.copy()
-        pg[2] = 1e-10                           ## avoid division by 0
-        plt.plot( xx, VoigtModel().result( xx, pg ), 'r.' )
-        plt.show()
-
-    def plotPseudoVoigtModel( self ) :
-        self.testPseudoVoigtModel( )
-        xx = numpy.linspace( -1, +1, 1001 )
-        pvm = PseudoVoigtModel()
-        gm = GaussModel()
-        lm = LorentzModel()
-        par = numpy.asarray( [1.2,-0.2,0.3,0.3], dtype=float )
-        plt.plot( xx, pvm.result( xx, par ), 'r-', linewidth=2 )
-        plt.plot( xx, gm.result( xx, par[[0,1,2]] ), 'b-' )
-        pg = par.copy()
-        pg[3] = 0
-        plt.plot( xx, lm.result( xx, par[[0,1,3]] ), 'g-' )
-        plt.plot( xx, pvm.result( xx, pg ), 'c--' )
-        pg = par.copy()
-        pg[3] = 1.0
-        plt.plot( xx, pvm.result( xx, pg ), 'm--' )
-        plt.show()
-
-    def plotLogisticModel( self ) :
-        self.testLogisticModel( plot=True )
-
-    def plotLorentzModel( self ) :
-        self.testLorentzModel( plot=True )
-
-    def plotFreeShapeModel( self ) :
-        self.testFreeShapeModel( plot=True )
-
-    def plotGaussModel( self ) :
-        self.testGaussModel( plot=True )
-
-    def plotGaussPlusBackgroundModel( self ) :
-        self.testGaussPlusBackgroundModel( plot=True )
-
-    def plotHarmonicModel( self ) :
-        self.testHarmonicModel( plot=True )
-
-    def plotPolynomialModel( self ) :
-        self.testPolynomialModel( plot=True )
-
-    def plotChebyshevPolynomialModel( self ) :
-        self.testChebyshevPolynomialModel( plot=True )
-
-    def plotPadeModel( self ) :
-        self.testPadeModel( plot=True )
-
-    def plotPowerLawModel( self ) :
-        self.testPowerLawModel( plot=True )
-
-    def plotPowerModel( self ) :
-        self.testPowerModel( plot=True )
-
-    def plotRadialVelocityModel( self ) :
-        self.testRadialVelocityModel( plot=True )
-
-    def plotSincModel( self ) :
-        self.testSincModel( plot=True )
-
-    def plotSineModel( self ) :
-        self.testSineModel( plot=True )
-
-    def plotPhaseSineModel( self ) :
-        self.testPhaseSineModel( plot=True )
-
-    def plotSineAmpModel( self ) :
-        self.testSineAmpModel( plot=True )
-
-    def plotSineSplineModel( self ) :
-        self.testSineSplineModel( plot=True )
-
-    def plotSineSplineDriftModel( self ) :
-        self.testSineSplineDriftModel( plot=True )
-
-    def plotSineDriftModel( self ) :
-        self.testSineDriftModel( plot=True )
-
-    def plotBSplinesModel( self ) :
-        self.testBSplinesModel( plot=True )
-
-    def plotSplinesModel( self ) :
-        self.testSplinesModel( plot=True )
-
-
-    def testArctanModel( self, plot=False ):
+    def testArctanModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******ARCTAN***********************" )
         m = ArctanModel( )
         p = numpy.asarray( [1.2,-0.1,30], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testArctanFixedModel( self, plot=False ):
+    def testArctanFixedModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******ARCTAN FIXED******************" )
         m = ArctanModel( fixed={1:-1.2} )
         p = numpy.asarray( [1.2,30], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testConstantModel( self, plot=False ):
+    def testConstantModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******NULL***********************" )
         m = ConstantModel( )
@@ -223,74 +92,76 @@ class TestModels( unittest.TestCase ):
         self.assertTrue( m.npbase == 0 )
         self.assertTrue( m.npchain == 2 )
         p = [1.0, -3.0]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testEtalonModel( self, plot=False ):
+    def testEtalonModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******ETALON***********************" )
         m = EtalonModel( )
         p = numpy.asarray( [1.2, 0.6, 2.0, 0.2], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testExpModel( self, plot=False ):
+    def testExpModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******EXP**************************" )
         m = ExpModel( )
         p = numpy.asarray( [1.2,-0.1], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testLogisticModel( self, plot=False ):
+    def testLogisticModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******LOGISTIC***********************" )
         m = LogisticModel( )
         p = numpy.asarray( [1.2,-0.2,0.3], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testLorentzModel( self, plot=False ):
+    def testLorentzModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******LORENTZ***********************" )
         m = LorentzModel( )
         p = numpy.asarray( [1.2,-0.2,0.3], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testVoigtModel( self, plot=False ):
+    def testVoigtModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******VOIGT***********************" )
         m = VoigtModel( )
         p = numpy.asarray( [1.2,0.2,0.3,0.4], dtype=float )
         print( p )
-        stdModeltest( m, p, plot=plot ) #, warn=["nopart"] )
 
-    def testPseudoVoigtModel( self, plot=False ):
+        stdModeltest( m, p, plot=self.doplot ) #, warn=["nopart"] )
+
+    def testPseudoVoigtModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******PSEUDOVOIGT***********************" )
         m = PseudoVoigtModel( )
         p = numpy.asarray( [1.2,0.2,0.3,0.4], dtype=float )
         print( p )
-        stdModeltest( m, p, plot=plot )
 
-    def testFreeShapeModel( self, plot=False ):
+        stdModeltest( m, p, plot=self.doplot )
+
+    def testFreeShapeModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******FREESHAPE********************" )
         m = FreeShapeModel( 5, pixperbin=1, xlo=-1, xhi=1.1, nconvolve=2 )
         self.assertTrue( m.npbase == 5 )
         p = numpy.asarray( [1.2,0.2,1.0,0.5,0.3], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testGaussModel( self, plot=False ):
+    def testGaussModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******GAUSS*************************" )
         m = GaussModel( )
         p = numpy.asarray( [1.2,-0.2,0.3], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testGaussPlusBackgroundModel( self, plot=False ):
+    def testGaussPlusBackgroundModel( self ):
         print( "******GAUSS + BG**********************" )
         gm = GaussModel( )
         print( gm )
@@ -301,9 +172,9 @@ class TestModels( unittest.TestCase ):
         gm.addModel( pm )
         par = numpy.asarray( [3,0.2,0.2,0.1,0.1], dtype=float )
 
-        stdModeltest( gm, par, plot=plot )
+        stdModeltest( gm, par, plot=self.doplot )
 
-    def testHarmonicModel( self, plot=False ):
+    def testHarmonicModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******HARMONIC**********************" )
         m = HarmonicModel( 1 )
@@ -318,18 +189,19 @@ class TestModels( unittest.TestCase ):
 
         p = numpy.asarray( [1.2,-0.2,0.3,1.2,-0.2,0.3], dtype=float )
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testPolynomialModel( self, plot=False ):
+    def testPolynomialModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******POLYNOMIAL**********************" )
         m = PolynomialModel( 3 )
         self.assertTrue( m.getNumberOfParameters( ) == 4 )
         self.assertTrue( m.npbase == 4 )
         p = numpy.asarray( [1,-2,3,-2], dtype=float )
-        stdModeltest( m, p, plot=plot )
 
-    def testFixedPolynomialModel( self, plot=False ):
+        stdModeltest( m, p, plot=self.doplot )
+
+    def testFixedPolynomialModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******POLYNOMIAL FIXED****************" )
         m = PolynomialModel( 5, fixed={1:0.4, 3:-1.2} )
@@ -337,52 +209,54 @@ class TestModels( unittest.TestCase ):
         self.assertTrue( m.npbase == 4 )
         self.assertTrue( m.npmax == 6 )
         p = numpy.asarray( [1,-2,3,-2], dtype=float )
-        stdModeltest( m, p, plot=plot )
 
-    def testChebyshevPolynomialModel( self, plot=False ):
+        stdModeltest( m, p, plot=self.doplot )
+
+    def testChebyshevPolynomialModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******CHEBYSHEV POLYNOMIAL*************" )
         m = ChebyshevPolynomialModel( 4 )
         self.assertTrue( m.getNumberOfParameters( ) == 5 )
         self.assertTrue( m.npbase == 5 )
         p = numpy.asarray( [1,-2,3,-2,0.3], dtype=float )
-        stdModeltest( m, p, plot=plot )
 
-    def testPadeModel( self, plot=False ):
+        stdModeltest( m, p, plot=self.doplot )
+
+    def testPadeModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******PADE**********************" )
         m = PadeModel( 3, 2 )
         self.assertTrue( m.getNumberOfParameters( ) == 6 )
         self.assertTrue( m.npbase == 6 )
         p =  numpy.asarray( [1,-2,3,-2,0.3,1], dtype=float )
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testPowerLawModel( self, plot=False ):
+    def testPowerLawModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******POWERLAW*******************" )
         m = PowerLawModel( )
         self.assertTrue( m.npchain == 3 )
         self.assertTrue( m.npbase == 3 )
         p = [2.3, -1.1, 0.5]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testPowerModel( self, plot=False ):
+    def testPowerModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******POWER**********************" )
         m = PowerModel( 3 )
         self.assertTrue( m.getNumberOfParameters( ) == 1 )
         self.assertTrue( m.npbase == 1 )
         p = [2.3]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testRadialVelocityModel( self, plot=False ):
+    def testRadialVelocityModel( self ):
         x  = numpy.linspace( 0, 1400, 1401, dtype=float )
         print( "******RADIALVELOCITY***************" )
         m = RadialVelocityModel( )
         self.assertTrue( m.npars == 5 )
         self.assertTrue( m.npbase == 5 )
         p = [0.67, 130, 1200.0, 4.0, 3.0]
-        if plot :
+        if self.doplot :
             for p3 in range( 7 ) :
                 p[4] = 0.7 + 0.5 * p3
                 y = m.result( x, p )
@@ -392,45 +266,64 @@ class TestModels( unittest.TestCase ):
 
             plt.show()
 
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSincModel( self, plot=False ):
+    def testRadialVelocityModel_2( self ):
+        x  = numpy.linspace( 0, 1400, 1401, dtype=float )
+        print( "******RADIALVELOCITY***************" )
+        m = RadialVelocityModel( spherical=False )
+        self.assertTrue( m.npars == 5 )
+        self.assertTrue( m.npbase == 5 )
+        p = [0.67, 130, 1200.0, 4.0, 3.0]
+        if self.doplot :
+            for p3 in range( 7 ) :
+                p[4] = 0.7 + 0.5 * p3
+                y = m.result( x, p )
+                plt.plot( x, y + 100 * p3, '-' )
+#                yo = m.baseResultXXX( x, p )
+#                plt.plot( x, yo + 100 * p3, '.' )
+
+            plt.show()
+
+        stdModeltest( m, p, plot=self.doplot )
+
+    def testSincModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINC***********************" )
         m = SincModel( )
         self.assertTrue( m.npchain == 3 )
         self.assertTrue( m.npbase == 3 )
         p = [2.3, -1.1, 0.5]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSineModel( self, plot=False ):
+    def testSineModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINE***********************" )
         m = SineModel( )
         self.assertTrue( m.npchain == 3 )
         self.assertTrue( m.npbase == 3 )
         p = [1.3, -1.1, 0.5]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testPhaseSineModel( self, plot=False ):
+    def testPhaseSineModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINE***********************" )
         m = SineModel( phase=True )
         self.assertTrue( m.npchain == 3 )
         self.assertTrue( m.npbase == 3 )
         p = [1.3, -1.1, 0.5]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSineAmpModel( self, plot=False ):
+    def testSineAmpModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINEAMP********************" )
         m = SineAmpModel( 1.3 )
         self.assertTrue( m.npchain == 2 )
         self.assertTrue( m.npbase == 2 )
         p = [-1.1, 0.5]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSineSplineModel( self, plot=False ):
+    def testSineSplineModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINESPLINE******************" )
         knots = numpy.arange( 3, dtype=float ) - 1
@@ -440,9 +333,9 @@ class TestModels( unittest.TestCase ):
         p = [0.0, 0.5, -0.1, 0.5, -0.1, 0.0, +1.1, 0.5, -1.1, -0.5]
         amp = m.getAmplitudes( x, p )
         print( amp[0], amp[1] )
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSineSplineDriftModel( self, plot=False ):
+    def testSineSplineDriftModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINESPLINEDRIFT*************" )
         knots = numpy.arange( 3, dtype=float ) - 1
@@ -453,18 +346,18 @@ class TestModels( unittest.TestCase ):
         p = [0.0, 0.1, 0.0, 0.5, -0.1, 0.5, -0.1, 0.0, +1.1, 0.5, -1.1, -0.5]
         amp = m.getAmplitudes( x, p )
         print( amp[0], amp[1] )
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testSineDriftModel( self, plot=False ):
+    def testSineDriftModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SINEDRIFT******************" )
         m = SineDriftModel( )
         self.assertTrue( m.npchain == 4 )
         self.assertTrue( m.npbase == 4 )
         p = [1.1, 0.5, 0.8, 0.4 ]
-        stdModeltest( m, p, plot=plot )
+        stdModeltest( m, p, plot=self.doplot )
 
-    def testBSplinesModel( self, plot=False ):
+    def testBSplinesModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******B-SPLINES*************************" )
         knots = numpy.arange( 11, dtype=float )
@@ -487,13 +380,44 @@ class TestModels( unittest.TestCase ):
 
         self.assertRaises( ValueError, BSplinesModel )
 
-        m1 = BSplinesModel( nrknots=5, order=3, min=-1, max=1 )
+        m1 = BSplinesModel( nrknots=5, order=3, min=-1.01, max=1.01 )
         p = numpy.asarray( [2,1,2,1,2,1,2], dtype=float )
         p = p[:m1.npchain]
         print( m1.npchain, p )
-        stdModeltest( m1, p, plot=plot )
+        stdModeltest( m1, p, plot=self.doplot )
 
-    def testSplinesModel( self, plot=False ):
+    def testBasicSplinesModel( self ):
+        x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
+        print( "******BASICSPLINES*************************" )
+        knots = numpy.arange( 11, dtype=float )
+        m0 = BasicSplinesModel( knots=knots )
+        self.assertTrue( m0.order == 3 )
+        self.assertTrue( m0.getNumberOfParameters( ) == 13 )
+        self.assertTrue( m0.npbase == 13 )
+
+        m1 = BasicSplinesModel( nrknots=5, min=-1, max=1 )
+        self.assertTrue( m1.order == 3 )
+        self.assertTrue( m1.getNumberOfParameters( ) == 7 )
+        self.assertTrue( m1.npbase == 7 )
+        for k in range( len( m1.knots ) ) :
+            self.assertTrue( m1.knots[k] == -1 + k / 2 )
+
+        xin = numpy.linspace( 0, 10, 101, dtype = float )
+        m2 = BasicSplinesModel( xrange=xin, order=2, nrknots=11 )
+        self.assertTrue( m2.order == 2 )
+        self.assertTrue( m2.getNumberOfParameters( ) == 12 )
+        self.assertTrue( m2.npbase == 12 )
+        for k in range( len( m2.knots ) ) :
+            self.assertTrue( m2.knots[k] == k )
+
+        self.assertRaises( ValueError, BasicSplinesModel )
+
+        m1 = BasicSplinesModel( nrknots=5, order=3, min=-1.01, max=1.01 )
+        p = numpy.asarray( [2,1,2,1,2,1,2], dtype=float )
+        print( m1.npchain, p )
+        stdModeltest( m1, p, plot=self.doplot )
+
+    def testSplinesModel( self ):
         x  = numpy.asarray( [-1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0] )
         print( "******SPLINES*************************" )
         knots = numpy.arange( 11, dtype=float )
@@ -501,12 +425,14 @@ class TestModels( unittest.TestCase ):
         self.assertTrue( m0.order == 3 )
         self.assertTrue( m0.getNumberOfParameters( ) == 13 )
         self.assertTrue( m0.npbase == 13 )
+
         m1 = SplinesModel( nrknots=5, min=-1, max=1 )
         self.assertTrue( m1.order == 3 )
         self.assertTrue( m1.getNumberOfParameters( ) == 7 )
         self.assertTrue( m1.npbase == 7 )
         for k in range( len( m1.knots ) ) :
             self.assertTrue( m1.knots[k] == -1 + k / 2 )
+
         xin = numpy.linspace( 0, 10, 101, dtype = float )
         m2 = SplinesModel( xrange=xin, order=2, nrknots=11 )
         self.assertTrue( m2.order == 2 )
@@ -517,7 +443,7 @@ class TestModels( unittest.TestCase ):
         self.assertRaises( ValueError, SplinesModel )
 
         p = numpy.asarray( [0,1,0,1,0,1,0], dtype=float )
-        stdModeltest( m1, p, plot=plot )
+        stdModeltest( m1, p, plot=self.doplot )
 
 
 
